Skip to contents

Returns controlled vocabulary options for IHO ocean regions.

Usage

areas_vocabulary()

Value

A character vector of ocean name options

Details

Provides ocean and sea names from the International Hydrographic Organisation (IHO) regions dataset, downloaded from https://www.marineregions.org/download_file.php?name=World_Seas_IHO_v3.zip. Wrapper for ocean_vocabulary() used to maintain compatibility. The complete list is read from an internal data file (IHO_oceans.rds) and includes options such as:

Not relevant

Not reported

Other

All IHO ocean region names (e.g., Arctic Ocean, Atlantic Ocean, Baltic Sea, Mediterranean Sea, ...)

Data source: extdata/IHO_oceans.rds