Skip to contents

Returns controlled vocabulary options for spatial coordinate reference systems.

Usage

coordinate_systems_vocabulary(common_only = TRUE)

Arguments

common_only

Return only the most common CRS options (default TRUE)

Value

A character vector of coordinate system options

Details

Sourced from the EPSG Dataset via the crsuggest package.

More CRS will be added as needed. In the long term, vocabulary may be replaced entirely for better standardisation with EPSG and/or PROJ4String.

CRS data sourced from crsuggest (Walker 2022). Using the EPSG Dataset v10.019, a product of the International Association of Oil & Gas Producers. Please view the terms of use at https://epsg.org/terms-of-use.html.

Examples

head(coordinate_systems_vocabulary(), 5)
#> [1] "Not relevant" "Not reported" "Other"        "WGS 84"       "ETRS89"