Controlled vocabulary for the DATA_SOURCE column, References table
Source:R/fct_vocabulary.R
data_source_vocabulary.RdReturns the set of valid values for the DATA_SOURCE field in the
Reference table.
R/fct_vocabulary.R
data_source_vocabulary.RdReturns the set of valid values for the DATA_SOURCE field in the
Reference table.