Skip to contents

Returns extraction protocol options with short and long names.

Usage

extraction_protocols_vocabulary()

Value

A tibble with Protocol_Type, Short_Name, and Long_Name columns

Details

Provides standardised extraction method classifications as a tibble with three columns:

Protocol_Type: Always "Extraction Protocol"

Short_Name: Abbreviated protocol name (e.g., "Methanol", "SPE Isolute Env+", "QuEChERS")

Long_Name: Full descriptive name (e.g., "Methanol extraction", "Solid phase extraction with Isolute Env+ cartridge", "Quick easy cheap effective rugged safe extraction")

Available protocols include: Not relevant, Not reported, None, Methanol, Dichloromethane, SPE Isolute Env+, Membrane filtration 0.45um, Membrane filtration 0.2um, Membrane filtration, Filtration, Microwave-assisted acid digestion, Acid digestion, Pressurised liquid, Ultrasonic, Soxhlet, QuEChERS, Accelerated solvent, Sequential extraction, Other

Examples

head(extraction_protocols_vocabulary(), 5)
#> # A tibble: 5 × 3
#>   Protocol_Type       Short_Name      Long_Name                 
#>   <chr>               <chr>           <chr>                     
#> 1 Extraction Protocol Not relevant    Not relevant              
#> 2 Extraction Protocol Not reported    Not reported              
#> 3 Extraction Protocol None            No extraction             
#> 4 Extraction Protocol Methanol        Methanol extraction       
#> 5 Extraction Protocol Dichloromethane Dichloromethane extraction