Skip to contents

Creates an empty tibble with the standardised column structure for sample data.

Usage

initialise_samples_tibble()

Value

A tibble with 0 rows and standardised sample columns

Details

Samples represent individual collections from sites with temporal, spatial, and methodological information linking sites, parameters, and compartments. The tibble includes the following columns:

SITE_CODE: Code identifying the sampling location

SITE_NAME: Descriptive name of the sampling site

PARAMETER_NAME: Name of the measured parameter

PARAMETER_TYPE: Classification of the parameter

ENVIRON_COMPARTMENT: Environmental compartment defined as one of the earth's spheres (aquatic, atmospheric, etc.)

ENVIRON_COMPARTMENT_SUB: Sub-divisions of environmental compartments into water body types, soil profile, etc.

MEASURED_CATEGORY: Measurement context category

SAMPLING_DATE: Date of sample collection

SUBSAMPLE: Subsample or replicate identifier

SUBSAMPLE_ID: Unique identifier for the subsample

SAMPLE_ID: Unique identifier for the sample (Key)

See vignette("samples_data") for more information.