Skip to contents

Returns controlled vocabulary options for measurement context categories.

Usage

measured_categories_vocabulary()

Value

A named character vector of measured category options

Details

Provides standardised categories indicating where measurements were taken relative to organisms (inside an organism, from its surface, or external to the organism (default))

Examples

measured_categories_vocabulary()
#>               External               Internal                Surface 
#>       "External Media" "Internal to Organism"  "Surface of Organism"