Skip to contents

Returns controlled vocabulary options for IHO ocean regions.

Usage

ocean_vocabulary()

Value

A character vector of sea and ocean name options

Details

Provides ocean and sea names from the International Hydrographic Organisation (IHO) regions dataset, regions dataset (https://www.marineregions.org/downloads.php, World Seas IHO v3).

Examples

head(ocean_vocabulary(), 15)
#>  [1] "Not relevant"       "Not reported"       "Other"             
#>  [4] "Torres Strait"      "Tasman Sea"         "Solomon Sea"       
#>  [7] "Ross Sea"           "Coral Sea"          "Bismarck Sea"      
#> [10] "Bellingshausen Sea" "Bass Strait"        "Amundsen Sea"      
#> [13] "Timor Sea"          "Sunda Strait"       "Sumba Strait"