Skip to contents

Applies pointblank validation rules to check data quality and schema compliance for a CREED relevance data table in the format produced by example_CREED_relevance_tibble(). Checks that criterion IDs and titles are within the expected sets, scores are integers between 0 and 4, and required/recommended classification is valid.

Usage

pb_validate_CREED_data_relevance(data, actions = action_levels(), agent = TRUE)

Arguments

data

Data frame containing CREED relevance data to validate

actions

Action levels for pointblank agent (only used when agent = TRUE)

agent

Logical. If TRUE (default), returns a pointblank agent object. If FALSE, returns the validated data with validation failures removed.

Value

If agent = TRUE, a pointblank agent object containing validation results. If agent = FALSE, the input data with validation failures removed.

Details

Validation thresholds are configured using pointblank::action_levels().

Examples

if (FALSE) { # \dontrun{
pb_validate_CREED_data_relevance(example_CREED_relevance_tibble())
} # }