Skip to contents

Applies pointblank validation rules to check data quality and schema compliance for an eData CREED Scores table. Checks that reference IDs match the format produced by generate_reference_id(), are non-null, are not the placeholder value, and that reliability and relevance classification fields contain valid values.

Usage

pb_validate_CREED_scores(data, actions = action_levels(), agent = TRUE)

Arguments

data

Data frame containing CREED Scores table data to validate

actions

Action levels for pointblank agent (only used when agent = TRUE)

agent

Logical. If TRUE (default), returns a pointblank agent object. If FALSE, returns the validated data with validation failures removed.

Value

If agent = TRUE, a pointblank agent object containing validation results. If agent = FALSE, the input data with validation failures removed.

Details

Validation thresholds are configured using pointblank::action_levels().

Examples

if (FALSE) { # \dontrun{
pb_validate_CREED_scores(example_CREED_scores_tibble())
} # }