Skip to contents

Applies pointblank validation rules to check data quality and schema compliance for an eData Methods table. Checks that protocol IDs match the format produced by generate_protocol_id(), that protocol ID and campaign name fields are non-null, and that protocol category and name values are within their controlled vocabularies.

Usage

pb_validate_methods(data, actions = action_levels(), agent = TRUE)

Arguments

data

Data frame containing Methods table data to validate

actions

Action levels for pointblank agent (only used when agent = TRUE)

agent

Logical. If TRUE (default), returns a pointblank agent object. If FALSE, returns the validated data with validation failures removed.

Value

If agent = TRUE, a pointblank agent object containing validation results. If agent = FALSE, the input data with validation failures removed.

Details

Validation thresholds are configured using pointblank::action_levels().

Examples

if (FALSE) { # \dontrun{
pb_validate_methods(example_methods_tibble())
} # }