Skip to contents

Returns sampling protocol options with short and long names.

Usage

sampling_protocols_vocabulary()

Value

A tibble with Protocol_Type, Short_Name, and Long_Name columns

Details

Provides standardised sampling method classifications as a tibble with three columns:

Protocol_Type: Always "Sampling Protocol"

Short_Name: Abbreviated protocol name (e.g., "Point", "Composite", "Trawl")

Long_Name: Full descriptive name (e.g., "Point sampling", "Composite sampling", "Trawl sampling")

Available protocols include: Not relevant, Not reported, Point, Composite, Trawl, Grab, Core, Seine net, Electrofishing, Plankton net, Bailer, Peristaltic pump, Active air, Passive air, SPMD, SPE, LVSPE, DGT, Caged organisms, Blood sample, Biopsy, Other

Examples

head(sampling_protocols_vocabulary(), 5)
#> # A tibble: 5 × 3
#>   Protocol_Type     Short_Name   Long_Name         
#>   <chr>             <chr>        <chr>             
#> 1 Sampling Protocol Not relevant Not relevant      
#> 2 Sampling Protocol Not reported Not reported      
#> 3 Sampling Protocol Point        Point sampling    
#> 4 Sampling Protocol Composite    Composite sampling
#> 5 Sampling Protocol Trawl        Trawl sampling