Generate compact reference ID (YYYYLNameFirstThreeWords) for REFERENCE_ID in References table
Source: R/fct_generate_IDs.R
generate_reference_id.RdCreates a compact reference identifier by combining the publication year, first author's last name, and the first three words of the title in PascalCase.
Arguments
- date
Integer or character. Publication year (e.g.
2018).Character. Semicolon-separated author list in "Last, First" format. Only the first author's last name is used (truncated to 10 alphanumeric characters).
- title
Character. Publication title. The first three words are extracted and converted to PascalCase.
See also
Other generate_id:
abbreviate_string(),
generate_protocol_id(),
generate_sample_id_with_components(),
protocol_id_regex(),
sample_id_regex()
Other reference:
example_references_tibble(),
initialise_references_tibble()