Creates an empty tibble with the standardised column structure for environmental compartment data.
Details
Compartments define the environmental matrix and measurement context for sampling activities. The compartments table is not a direct output of the eData format but is used to construct the samples table. The tibble includes the following columns:
ENVIRON_COMPARTMENT: Broad environmental compartment (Aquatic, Atmospheric, Terrestrial, Biota)
ENVIRON_COMPARTMENT_SUB: Specific sub-category within the compartment
MEASURED_CATEGORY: Measurement context (External Media, Internal to Organism, Surface of Organism)
See vignette("compartments_data") for more information.
See also
Other initialise_tibble:
initialise_CREED_data_tibble(),
initialise_CREED_scores_tibble(),
initialise_biota_tibble(),
initialise_campaign_tibble(),
initialise_measurements_tibble(),
initialise_methods_tibble(),
initialise_parameters_tibble(),
initialise_references_tibble(),
initialise_samples_tibble(),
initialise_sites_tibble()
Other compartment:
environ_compartments_sub_vocabulary(),
environ_compartments_vocabulary(),
measured_categories_vocabulary()