Creates an empty tibble with the standardised column structure for analytical methods data.
Details
Methods describe the protocols used for sampling, extraction, fractionation, and analysis procedures. The tibble includes the following columns:
PROTOCOL_ID: Unique identifier for the protocol (Primary Key)
CAMPAIGN_NAME: Name of the campaign this protocol was used in
PROTOCOL_CATEGORY: Type of protocol (Sampling, Extraction, Fractionation, Analytical)
PROTOCOL_NAME: Standardised name of the protocol
PROTOCOL_COMMENT: Additional notes or details about the protocol
See vignette("methods_data") for more information.
See also
Other initialise_tibble:
initialise_CREED_data_tibble(),
initialise_CREED_scores_tibble(),
initialise_biota_tibble(),
initialise_campaign_tibble(),
initialise_compartments_tibble(),
initialise_measurements_tibble(),
initialise_parameters_tibble(),
initialise_references_tibble(),
initialise_samples_tibble(),
initialise_sites_tibble()
Other method:
analytical_protocols_vocabulary(),
extraction_protocols_vocabulary(),
fractionation_protocols_vocabulary(),
protocol_categories_vocabulary(),
protocol_options_vocabulary(),
sampling_protocols_vocabulary()