Creates an empty tibble with the standardised column structure for reference data.
Details
References provide bibliographic information for data sources including journals, reports, datasets, and other published materials. The tibble includes the following columns:
REFERENCE_ID: Unique identifier for the reference (Primary Key)
REFERENCE_TYPE: Type of publication (Journal Article, Report, Dataset, etc.)
DATA_SOURCE: Whether reference is source of data (Primary, Secondary/Review, Other)
AUTHOR: Author(s) of the reference
TITLE: Title of the publication or document
YEAR: Publication year
ACCESS_DATE: Date when the reference was accessed or retrieved
PERIODICAL_JOURNAL: Name of the journal or periodical
VOLUME: Volume number of the journal
ISSUE: Issue number of the journal
PUBLISHER: Publisher of the document
INSTITUTION: Institution associated with the publication
DOI: Digital Object Identifier
URL: Web address for online access
ISBN_ISSN: ISBN or ISSN identifier
EDITION: Edition of the publication
DOCUMENT_NUMBER: Document or report number
REF_COMMENT: Additional notes about the reference
See vignette("references_data") for more information.
See also
Other initialise_tibble:
initialise_CREED_data_tibble(),
initialise_CREED_scores_tibble(),
initialise_biota_tibble(),
initialise_campaign_tibble(),
initialise_compartments_tibble(),
initialise_measurements_tibble(),
initialise_methods_tibble(),
initialise_parameters_tibble(),
initialise_samples_tibble(),
initialise_sites_tibble()
Other reference:
reference_character_limits()