Controlled vocabulary for the MEASURED_CATEGORY column, Compartments table
Source: R/fct_vocabulary.R
measured_categories_vocabulary.RdReturns controlled vocabulary options for measurement context categories.
Details
Provides standardised categories indicating where measurements were taken relative to organisms (inside an organism, from its surface, or external to the organism (default))
See also
Other compartment:
environ_compartments_sub_vocabulary(),
environ_compartments_vocabulary(),
example_compartments_tibble(),
initialise_compartments_tibble()
Other measurement:
example_measurements_tibble(),
initialise_measurements_tibble(),
measured_flag_vocabulary(),
measured_types_vocabulary(),
parameter_unit_vocabulary(),
uncertainty_types_vocabulary()